@@ -6,19 +6,18 @@ in the source distribution for its full text.
 */
 
 #define _GNU_SOURCE
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
-#include <curses.h>
-#include <stdarg.h>
-
+#include "RichString.h"
 #include "Meter.h"
 #include "Object.h"
 #include "CRT.h"
 #include "ListItem.h"
 #include "String.h"
 #include "ProcessList.h"
-#include "RichString.h"
+
+#include <math.h>
+#include <string.h>
+#include <stdlib.h>
+#include <stdarg.h>
 
 #include "debug.h"
 #include <assert.h>
@@ -98,6 +97,7 @@ typedef enum {
 #include "UptimeMeter.h"
 #include "BatteryMeter.h"
 #include "ClockMeter.h"
+#include "HostnameMeter.h"
 
 
 #ifndef MIN
@@ -124,6 +124,7 @@ MeterType* Meter_types[] = {
    &UptimeMeter,
    &BatteryMeter,
    &AllCPUsMeter,
+   &HostnameMeter,
    NULL
 };
 
