@@ -8,12 +8,14 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <curses.h>
+#include <ctype.h>
 
 #include "debug.h"
 #include <assert.h>
 #ifdef HAVE_LIBNCURSESW
-#include <wchar.h>
+#include <ncursesw/curses.h>
+#else
+#include <curses.h>
 #endif
 
 #define RICHSTRING_MAXLEN 300
@@ -89,7 +91,8 @@ int RichString_findChar(RichString *this, char c, int start) {
 inline void RichString_appendn(RichString* this, int attrs, char* data_c, int len) {
    int last = MIN(RICHSTRING_MAXLEN - 1, len + this->len);
    for (int i = this->len, j = 0; i < last; i++, j++)
-      this->chstr[i] = data_c[j] | attrs;
+      this->chstr[i] = (isprint(data_c[j]) ? data_c[j] : '?') | attrs;
+
    this->chstr[last] = 0;
    this->len = last;
 }
@@ -114,6 +117,10 @@ int RichString_findChar(RichString *this, char c, int start) {
 
 #endif
 
+void RichString_prune(RichString* this) {
+   this->len = 0;
+}
+
 void RichString_setAttr(RichString *this, int attrs) {
    RichString_setAttrn(this, attrs, 0, this->len - 1);
 }
