@@ -19,10 +19,30 @@ in the source distribution for its full text.
 #include "debug.h"
 #include <assert.h>
 
-/* private property */
-static int SwapMeter_attributes[] = { SWAP };
+int SwapMeter_attributes[] = {
+   SWAP
+};
+
+static void SwapMeter_setValues(Meter* this, char* buffer, int len) {
+   long int usedSwap = this->pl->usedSwap;
+   this->total = this->pl->totalSwap;
+   this->values[0] = usedSwap;
+   snprintf(buffer, len, "%ld/%ldMB", (long int) usedSwap / 1024, (long int) this->total / 1024);
+}
+
+static void SwapMeter_display(Object* cast, RichString* out) {
+   char buffer[50];
+   Meter* this = (Meter*)cast;
+   long int swap = (long int) this->values[0];
+   RichString_init(out);
+   RichString_append(out, CRT_colors[METER_TEXT], ":");
+   sprintf(buffer, "%ldM ", (long int) this->total / 1024);
+   RichString_append(out, CRT_colors[METER_VALUE], buffer);
+   sprintf(buffer, "%ldk", swap);
+   RichString_append(out, CRT_colors[METER_TEXT], "used:");
+   RichString_append(out, CRT_colors[METER_VALUE], buffer);
+}
 
-/* private */
 MeterType SwapMeter = {
    .setValues = SwapMeter_setValues, 
    .display = SwapMeter_display,
@@ -34,23 +54,3 @@ MeterType SwapMeter = {
    .uiName = "Swap",
    .caption = "Swp"
 };
-
-void SwapMeter_setValues(Meter* this, char* buffer, int len) {
-   long int usedSwap = this->pl->usedSwap;
-   this->total = this->pl->totalSwap;
-   this->values[0] = usedSwap;
-   snprintf(buffer, len, "%ld/%ldMB", (long int) usedSwap / 1024, (long int) this->total / 1024);
-}
-
-void SwapMeter_display(Object* cast, RichString* out) {
-   char buffer[50];
-   Meter* this = (Meter*)cast;
-   long int swap = (long int) this->values[0];
-   RichString_prune(out);
-   RichString_append(out, CRT_colors[METER_TEXT], ":");
-   sprintf(buffer, "%ldM ", (long int) this->total / 1024);
-   RichString_append(out, CRT_colors[METER_VALUE], buffer);
-   sprintf(buffer, "%ldk", swap);
-   RichString_append(out, CRT_colors[METER_TEXT], "used:");
-   RichString_append(out, CRT_colors[METER_VALUE], buffer);
-}
