@@ -26,6 +26,7 @@ in the source distribution for its full text.
 #include "CategoriesPanel.h"
 #include "SignalsPanel.h"
 #include "TraceScreen.h"
+#include "OpenFilesScreen.h"
 #include "AffinityPanel.h"
 
 #include "config.h"
@@ -99,8 +100,10 @@ static void showHelp(ProcessList* pl) {
    addattrstr(CRT_colors[BAR_BORDER], "]");
    attrset(CRT_colors[DEFAULT_COLOR]);
    mvaddstr(6,0, "Type and layout of header meters are configurable in the setup screen.");
-   mvaddstr(7, 0, "Status: R: running; S: sleeping; T: traced/stopped; Z: zombie; D: disk sleep");
-
+   if (CRT_colorScheme == COLORSCHEME_MONOCHROME) {
+      mvaddstr(7, 0, "In monochrome, meters are displayed through different chars, in order: |#*@$%&");
+   }
+   mvaddstr( 8, 0, " Status: R: running; S: sleeping; T: traced/stopped; Z: zombie; D: disk sleep");
    mvaddstr( 9, 0, " Arrows: scroll process list             F5 t: tree view");
    mvaddstr(10, 0, " Digits: incremental PID search             u: show processes of a single user");
    mvaddstr(11, 0, "   F3 /: incremental name search            H: hide/show user threads");
@@ -108,14 +111,16 @@ static void showHelp(ProcessList* pl) {
    mvaddstr(13, 0, "  Space: tag processes                      F: cursor follows process");
    mvaddstr(14, 0, "      U: untag all processes");
    mvaddstr(15, 0, "   F9 k: kill process/tagged processes      P: sort by CPU%");
-   mvaddstr(16, 0, " + [ F7: lower priority (+ nice)            M: sort by MEM%");
-   mvaddstr(17, 0, " - ] F8: higher priority (root only)        T: sort by TIME");
+   mvaddstr(16, 0, " - ] F7: higher priority (root only)        M: sort by MEM%");
+   mvaddstr(17, 0, " + [ F8: lower priority (+ nice)            T: sort by TIME");
+#ifdef HAVE_PLPA
    if (pl->processorCount > 1)
       mvaddstr(18, 0, "      a: set CPU affinity                F4 I: invert sort order");
    else
+#endif
       mvaddstr(18, 0, "                                         F4 I: invert sort order");
    mvaddstr(19, 0, "   F2 S: setup                           F6 >: select sort column");
-   mvaddstr(20, 0, "   F1 h: show this help screen");
+   mvaddstr(20, 0, "   F1 h: show this help screen              l: list open files with lsof");
    mvaddstr(21, 0, "  F10 q: quit                               s: trace syscalls with strace");
 
    attrset(CRT_colors[HELP_BOLD]);
@@ -129,10 +134,12 @@ static void showHelp(ProcessList* pl) {
    mvaddstr(16, 0, " + [ F7"); mvaddstr(16,40, "    M");
    mvaddstr(17, 0, " - ] F8"); mvaddstr(17,40, "    T");
                                mvaddstr(18,40, " F4 I");
+#if HAVE_PLPA
    if (pl->processorCount > 1)
       mvaddstr(18, 0, "      a:");
+#endif
    mvaddstr(19, 0, "   F2 S"); mvaddstr(19,40, " F6 >");
-   mvaddstr(20, 0, "   F1 h");
+   mvaddstr(20, 0, "   F1 h"); mvaddstr(20,40, "    l");
    mvaddstr(21, 0, "  F10 q"); mvaddstr(21,40, "    s");
    attrset(CRT_colors[DEFAULT_COLOR]);
 
@@ -144,12 +151,12 @@ static void showHelp(ProcessList* pl) {
    clear();
 }
 
-static char* CategoriesFunctions[10] = {"      ", "      ", "      ", "      ", "      ", "      ", "      ", "      ", "      ", "Done  "};
+static char* CategoriesFunctions[] = {"      ", "      ", "      ", "      ", "      ", "      ", "      ", "      ", "      ", "Done  ", NULL};
 
 static void Setup_run(Settings* settings, int headerHeight) {
    ScreenManager* scr = ScreenManager_new(0, headerHeight, 0, -1, HORIZONTAL, true);
    CategoriesPanel* panelCategories = CategoriesPanel_new(settings, scr);
-   ScreenManager_add(scr, (Panel*) panelCategories, FunctionBar_new(10, CategoriesFunctions, NULL, NULL), 16);
+   ScreenManager_add(scr, (Panel*) panelCategories, FunctionBar_new(CategoriesFunctions, NULL, NULL), 16);
    CategoriesPanel_makeMetersPage(panelCategories);
    Panel* panelFocus;
    int ch;
@@ -160,7 +167,7 @@ static void Setup_run(Settings* settings, int headerHeight) {
 static bool changePriority(Panel* panel, int delta) {
    bool ok = true;
    bool anyTagged = false;
-   for (int i = 0; i < Panel_getSize(panel); i++) {
+   for (int i = 0; i < Panel_size(panel); i++) {
       Process* p = (Process*) Panel_get(panel, i);
       if (p->tag) {
          ok = Process_setPriority(p, p->nice + delta) && ok;
@@ -182,13 +189,13 @@ static HandlerResult pickWithEnter(Panel* panel, int ch) {
    return IGNORED;
 }
 
-static Object* pickFromList(Panel* panel, Panel* list, int x, int y, char** keyLabels, FunctionBar* prevBar) {
-   char* fuKeys[2] = {"Enter", "Esc"};
-   int fuEvents[2] = {13, 27};
+static Object* pickFromVector(Panel* panel, Panel* list, int x, int y, char** keyLabels, FunctionBar* prevBar) {
+   char* fuKeys[] = {"Enter", "Esc", NULL};
+   int fuEvents[] = {13, 27};
    if (!list->eventHandler)
       Panel_setEventHandler(list, pickWithEnter);
    ScreenManager* scr = ScreenManager_new(0, y, 0, -1, HORIZONTAL, false);
-   ScreenManager_add(scr, list, FunctionBar_new(2, keyLabels, fuKeys, fuEvents), x - 1);
+   ScreenManager_add(scr, list, FunctionBar_new(keyLabels, fuKeys, fuEvents), x - 1);
    ScreenManager_add(scr, panel, NULL, -1);
    Panel* panelFocus;
    int ch;
@@ -203,7 +210,7 @@ static Object* pickFromList(Panel* panel, Panel* list, int x, int y, char** keyL
    return NULL;
 }
 
-static void addUserToList(int key, void* userCast, void* panelCast) {
+static void addUserToVector(int key, void* userCast, void* panelCast) {
    char* user = (char*) userCast;
    Panel* panel = (Panel*) panelCast;
    Panel_add(panel, (Object*) ListItem_new(user, key));
@@ -268,6 +275,9 @@ int main(int argc, char** argv) {
          if (arg == argc - 1) printHelpFlag();
          arg++;
          setUserOnly(argv[arg], &userOnly, &userId);
+      } else {
+         fprintf(stderr, "Error: unknown flag: %s\n", argv[arg]);
+         exit(1);
       }
       arg++;
    }
@@ -282,6 +292,7 @@ int main(int argc, char** argv) {
    int refreshTimeout = 0;
    int resetRefreshTimeout = 5;
    bool doRefresh = true;
+   bool doRecalculate = false;
    Settings* settings;
    
    Panel* killPanel = NULL;
@@ -314,14 +325,14 @@ int main(int argc, char** argv) {
    }
    Panel_setRichHeader(panel, ProcessList_printHeader(pl));
    
-   char* searchFunctions[3] = {"Next  ", "Exit  ", " Search: "};
-   char* searchKeys[3] = {"F3", "Esc", "  "};
-   int searchEvents[3] = {KEY_F(3), 27, ERR};
-   FunctionBar* searchBar = FunctionBar_new(3, searchFunctions, searchKeys, searchEvents);
+   char* searchFunctions[] = {"Next  ", "Exit  ", " Search: ", NULL};
+   char* searchKeys[] = {"F3", "Esc", "  "};
+   int searchEvents[] = {KEY_F(3), 27, ERR};
+   FunctionBar* searchBar = FunctionBar_new(searchFunctions, searchKeys, searchEvents);
    
-   char* defaultFunctions[10] = {"Help  ", "Setup ", "Search", "Invert", "Tree  ",
-       "SortBy", "Nice -", "Nice +", "Kill  ", "Quit  "};
-   FunctionBar* defaultBar = FunctionBar_new(10, defaultFunctions, NULL, NULL);
+   char* defaultFunctions[] = {"Help  ", "Setup ", "Search", "Invert", "Tree  ",
+       "SortBy", "Nice -", "Nice +", "Kill  ", "Quit  ", NULL};
+   FunctionBar* defaultBar = FunctionBar_new(defaultFunctions, NULL, NULL);
 
    ProcessList_scan(pl);
    usleep(75000);
@@ -346,15 +357,15 @@ int main(int argc, char** argv) {
       if (recalculate)
          oldTime = newTime;
       if (doRefresh) {
-         incSearchIndex = 0;
-         incSearchBuffer[0] = 0;
          int currPos = Panel_getSelectedIndex(panel);
          unsigned int currPid = 0;
          int currScrollV = panel->scrollV;
          if (follow)
             currPid = ProcessList_get(pl, currPos)->pid;
-         if (recalculate)
+         if (recalculate || doRecalculate) {
             ProcessList_scan(pl);
+            doRecalculate = false;
+         }
          if (refreshTimeout == 0) {
             ProcessList_sort(pl);
             refreshTimeout = 1;
@@ -420,8 +431,6 @@ int main(int argc, char** argv) {
             incSearchBuffer[incSearchIndex] = 0;
          } else {
             incSearchMode = false;
-            incSearchIndex = 0;
-            incSearchBuffer[0] = 0;
             FunctionBar_draw(defaultBar, NULL);
             continue;
          }
@@ -507,7 +516,7 @@ int main(int argc, char** argv) {
       }
       case 'U':
       {
-         for (int i = 0; i < Panel_getSize(panel); i++) {
+         for (int i = 0; i < Panel_size(panel); i++) {
             Process* p = (Process*) Panel_get(panel, i);
             p->tag = false;
          }
@@ -553,6 +562,17 @@ int main(int argc, char** argv) {
          CRT_enableDelay();
          break;
       }
+      case 'l':
+      {
+         OpenFilesScreen* ts = OpenFilesScreen_new((Process*) Panel_getSelected(panel));
+         OpenFilesScreen_run(ts);
+         OpenFilesScreen_delete(ts);
+         clear();
+         FunctionBar_draw(defaultBar, NULL);
+         refreshTimeout = 0;
+         CRT_enableDelay();
+         break;
+      }
       case 'S':
       case 'C':
       case KEY_F(2):
@@ -576,12 +596,12 @@ int main(int argc, char** argv) {
       {
          Panel* usersPanel = Panel_new(0, 0, 0, 0, LISTITEM_CLASS, true, ListItem_compare);
          Panel_setHeader(usersPanel, "Show processes of:");
-         UsersTable_foreach(ut, addUserToList, usersPanel);
+         UsersTable_foreach(ut, addUserToVector, usersPanel);
          Vector_sort(usersPanel->items);
          ListItem* allUsers = ListItem_new("All users", -1);
          Panel_insert(usersPanel, 0, (Object*) allUsers);
-         char* fuFunctions[2] = {"Show    ", "Cancel "};
-         ListItem* picked = (ListItem*) pickFromList(panel, usersPanel, 20, headerHeight, fuFunctions, defaultBar);
+         char* fuFunctions[] = {"Show    ", "Cancel ", NULL};
+         ListItem* picked = (ListItem*) pickFromVector(panel, usersPanel, 20, headerHeight, fuFunctions, defaultBar);
          if (picked) {
             if (picked == allUsers) {
                userOnly = false;
@@ -599,15 +619,15 @@ int main(int argc, char** argv) {
             killPanel = (Panel*) SignalsPanel_new(0, 0, 0, 0);
          }
          SignalsPanel_reset((SignalsPanel*) killPanel);
-         char* fuFunctions[2] = {"Send  ", "Cancel "};
-         Signal* signal = (Signal*) pickFromList(panel, killPanel, 15, headerHeight, fuFunctions, defaultBar);
+         char* fuFunctions[] = {"Send  ", "Cancel ", NULL};
+         Signal* signal = (Signal*) pickFromVector(panel, killPanel, 15, headerHeight, fuFunctions, defaultBar);
          if (signal) {
             if (signal->number != 0) {
                Panel_setHeader(panel, "Sending...");
                Panel_draw(panel, true);
                refresh();
                bool anyTagged = false;
-               for (int i = 0; i < Panel_getSize(panel); i++) {
+               for (int i = 0; i < Panel_size(panel); i++) {
                   Process* p = (Process*) Panel_get(panel, i);
                   if (p->tag) {
                      Process_sendSignal(p, signal->number);
@@ -625,6 +645,7 @@ int main(int argc, char** argv) {
          refreshTimeout = 0;
          break;
       }
+#ifdef HAVE_PLPA
       case 'a':
       {
          if (pl->processorCount == 1)
@@ -635,13 +656,13 @@ int main(int argc, char** argv) {
          
          Panel* affinityPanel = AffinityPanel_new(pl->processorCount, curr);
 
-         char* fuFunctions[2] = {"Set    ", "Cancel "};
-         void* set = pickFromList(panel, affinityPanel, 15, headerHeight, fuFunctions, defaultBar);
+         char* fuFunctions[] = {"Set    ", "Cancel ", NULL};
+         void* set = pickFromVector(panel, affinityPanel, 15, headerHeight, fuFunctions, defaultBar);
          if (set) {
             unsigned long new = AffinityPanel_getAffinity(affinityPanel);
             bool anyTagged = false;
             bool ok = true;
-            for (int i = 0; i < Panel_getSize(panel); i++) {
+            for (int i = 0; i < Panel_size(panel); i++) {
                Process* p = (Process*) Panel_get(panel, i);
                if (p->tag) {
                   ok = Process_setAffinity(p, new) && ok;
@@ -660,6 +681,7 @@ int main(int argc, char** argv) {
          refreshTimeout = 0;
          break;
       }
+#endif
       case KEY_F(10):
       case 'q':
          quit = 1;
@@ -673,7 +695,7 @@ int main(int argc, char** argv) {
       {
          Panel* sortPanel = Panel_new(0, 0, 0, 0, LISTITEM_CLASS, true, ListItem_compare);
          Panel_setHeader(sortPanel, "Sort by");
-         char* fuFunctions[2] = {"Sort  ", "Cancel "};
+         char* fuFunctions[] = {"Sort  ", "Cancel ", NULL};
          ProcessField* fields = pl->fields;
          for (int i = 0; fields[i]; i++) {
             char* name = String_trim(Process_fieldTitles[fields[i]]);
@@ -682,7 +704,7 @@ int main(int argc, char** argv) {
                Panel_setSelected(sortPanel, i);
             free(name);
          }
-         ListItem* field = (ListItem*) pickFromList(panel, sortPanel, 15, headerHeight, fuFunctions, defaultBar);
+         ListItem* field = (ListItem*) pickFromVector(panel, sortPanel, 15, headerHeight, fuFunctions, defaultBar);
          if (field) {
             settings->changed = true;
             setSortKey(pl, field->key, panel, settings);
@@ -718,8 +740,10 @@ int main(int argc, char** argv) {
       }
       case KEY_F(3):
       case '/':
-         FunctionBar_draw(searchBar, incSearchBuffer);
+         incSearchIndex = 0;
+         incSearchBuffer[0] = 0;
          incSearchMode = true;
+         FunctionBar_draw(searchBar, incSearchBuffer);
          break;
       case 't':
       case KEY_F(5):
@@ -728,12 +752,14 @@ int main(int argc, char** argv) {
          settings->changed = true;
          break;
       case 'H':
+         doRecalculate = true;
          refreshTimeout = 0;
          pl->hideUserlandThreads = !pl->hideUserlandThreads;
          pl->hideThreads = pl->hideUserlandThreads;
          settings->changed = true;
          break;
       case 'K':
+         doRecalculate = true;
          refreshTimeout = 0;
          pl->hideKernelThreads = !pl->hideKernelThreads;
          settings->changed = true;
